# Padrões Desenvolvimento - PG

São seguidos os [Padrões de Desenvolvimento Gerais](http://gitlab.teknisa.com/pebbian/hcmservices/-/blob/master/PadroesDev.md). Esse documento lista os padrões específicos do PG.

## *Back-end*

### Rotas de Redirecionamento HS

Rotas com o único propósito de redirecionar a requisição para o HcmServices, poderão apenas indicar o redirecionamento na definição da rota.

```json
{
    "uri": "/rotaExemplo",
    "controller": "HcmServicesController",
    "controllerMethod": "fowardToHcmservices",
    "methods": ["GET"],
    "requestType": "FilterData"
},
```

### Verificação de Rota Existente

Ao criar ou modificar rotas no arquivo `routes.json`, é fundamental verificar se já existe uma rota com o mesmo nome. A existência de rotas duplicadas pode resultar em conflitos ou erros inesperados durante a execução. Recomenda-se realizar uma verificação simples para garantir a unicidade dos nomes das rotas


## *Front-end*

### Otimização de Requisições Paralelas

Ao realizar chamadas sequenciais de requisições que não dependem umas das outras, é vantajoso considerar a utilização de `Promise.all` ou `Promise.allSettled`. Essas abordagens permitem a execução simultânea das requisições, resultando em um tempo total de carregamento significativamente reduzido.

#### `Promise.all` para Requisições Concorrentes

```javascript
// Com promise.all
// Todas serão chamadas ao mesmo tempo.
try {
  const [resDaPrimeira, resDaSegunda, resDaTerceira] = await Promise.all([
    this.loadTipoAlteraSal(),
    this.loadModalidadeSal(),
    this.loadUltimoSalario()
  ]);
} catch (err) {
  console.log(err);
}
```

```javascript
// Sem promise.all
// Nesse caso a proxima requisição só será chamada quando a anterior encerrar por conta do "await".
try {
    const resDaPrimeira = await this.loadTipoAlteraSal();
    const resDaSegunda = await this.loadModalidadeSal();
    const resDaTerceira = await this.loadUltimoSalario();
} catch (err) {
  console.log(err);
}
```

#### `Promise.allsettled` para tratamentos de erros

Ao utilizar Promise.all, é importante observar que se uma das requisições falhar, o Promise.all retornará uma única promise rejeitada imediatamente com o erro da primeira promise que foi rejeitada.

Use o Promise.allSettled para Tratamento Individual de Erros 
caso seja necessário lidar com os erros de cada requisição de forma independente

```javascript
try {
  const results = await Promise.allSettled([
    this.loadTipoAlteraSal(),
    this.loadModalidadeSal(),
    this.loadUltimoSalario()
  ]);

  results.forEach(result => {
    if (result.status === 'fulfilled') {
      console.log('Resultado:', result.value);
      // Faça o que for necessário com o resultado bem-sucedido
    } else {
      console.log('Erro:', result.reason);
      // Trate o erro da promise individualmente
    }
  });

} catch (err) {
  console.log(err);
}
```