<?php
namespace tests\Zeedhi\Framework\Service;

use Zeedhi\Framework\Service\Translator;
use Zeedhi\Framework\HTTP\Kernel;

class TranslatorTest extends \PHPUnit\Framework\TestCase {
    /** @var string */
    private $dirPath;
    /** @var string */
    private $filePath;
    /** @var string */
    private $testPath;
    /** @var string */
    private $language;
    /** @var string */
    private $content;
    /** @var array */
    private $parsedContent;
    /** @var array */
    private $translations;
    /** @var array */
    private $variables;
    /** @var array */
    private $translatedFile;
    /** @var array */
    private $options;
    /** @var array */
    private $filesToTranslate;

    public function setUp(){
        $this->dirPath = './tests/mocks/metadataMock';
        $this->filePath = 'simpleJSON';
        $this->testPath = 'test';
        $this->language = 'pt_BR';
        $this->translations = [
            'first' => 'primeiro',
            'First obj' => 'Primeiro obj'
        ];
        $this->variables = [
            '__test__' => 'tested',
            '__variable__' => 'test',
        ];
        $this->parsedContent = [
            [
                'name' => 'first',
                'description' => 'First obj',
                'variable' => '__test__'
            ]
        ];
        $this->translatedFile = [
            [
                'name' => 'primeiro',
                'description' => 'Primeiro obj',
            ]
        ];
        $this->options = [
            'defaultLanguage' => 'en_US',
            'targetLanguage' => 'pt_BR',
        ];
        $this->content = json_encode($this->parsedContent, JSON_PRETTY_PRINT);
        $this->filesToTranslate = [
            realpath($this->dirPath.DIRECTORY_SEPARATOR.$this->filePath.'.json'),
            realpath($this->dirPath.DIRECTORY_SEPARATOR.'pt_BR.json'),
        ];
        Kernel::$metadataSource = $this->dirPath;
    }

    public function tearDown(){
        if($file = realpath($this->dirPath.DIRECTORY_SEPARATOR.$this->testPath)) unlink($file);
    }

    public function testGetTranslations(){
        $this->assertEquals(
            $this->translations,
            Translator::getTranslations($this->dirPath.DIRECTORY_SEPARATOR.'words', $this->language)
        );
    }

    public function testParseToArray(){
        $this->assertEquals(
            $this->parsedContent,
            Translator::parseToArray($this->content)
        );
    }

    public function testGetFileContent(){
        $this->assertEquals(
            $this->content,
            Translator::getFileContent(
                realpath($this->dirPath.DIRECTORY_SEPARATOR.$this->filePath.'.json')
            )
        );
    }

    public function testReplaceVariables(){
        $expected = [
            'my test',
        ];
        $content = [
            'my __variable__',
        ];
        $this->assertEquals(
            $expected,
            Translator::replaceVariables(
                $content,
                $this->variables
            )
        );
    }

    public function testTranslateWords(){
        $expected = [
            'primeiro',
            'Primeiro obj',
        ];
        $words = [
            'first',
            'First obj',
        ];
        $this->assertEquals(
            $expected,
            Translator::translateWords(
                $words,
                $this->translations
            )
        );
    }

    public function testTranslateAndDecode(){
        $expected = [
            [
                'name' => 'primeiro',
                'description' => 'Primeiro obj',
                'variable' => 'tested',
            ],
        ];
        $this->assertEquals(
            $expected,
            Translator::translateAndDecode(
                $this->parsedContent,
                Kernel::$metadataSource.DIRECTORY_SEPARATOR.'words',
                'pt_BR',
                $this->variables
            )
        );
    }
}
